summaryrefslogtreecommitdiff
path: root/plugins/Facebook/facebook/facebookapi_php5_restlib.php
diff options
context:
space:
mode:
authorBrion Vibber <brion@pobox.com>2009-11-09 20:01:46 +0100
committerBrion Vibber <brion@pobox.com>2009-11-09 20:01:46 +0100
commit088081675fb7d5250a9b9dfe5015de0822cb5ac2 (patch)
tree6b875217286883172802f0565291e2b4d15a8b5c /plugins/Facebook/facebook/facebookapi_php5_restlib.php
parent8e58f241739b97bd53f78035781f16e2067a31d9 (diff)
Revert "Remove more contractions"
This reverts commit 5ab709b73977131813884558bf56d97172a7aa26. Missed this one yesterday...
Diffstat (limited to 'plugins/Facebook/facebook/facebookapi_php5_restlib.php')
-rwxr-xr-xplugins/Facebook/facebook/facebookapi_php5_restlib.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/plugins/Facebook/facebook/facebookapi_php5_restlib.php b/plugins/Facebook/facebook/facebookapi_php5_restlib.php
index c742df748..55cb7fb86 100755
--- a/plugins/Facebook/facebook/facebookapi_php5_restlib.php
+++ b/plugins/Facebook/facebook/facebookapi_php5_restlib.php
@@ -46,7 +46,7 @@ class FacebookRestClient {
// on canvas pages
public $added;
public $is_user;
// we do not pass friends list to iframes, but we want to make
// friends_get really simple in the canvas_user (non-logged in) case.
// So we use the canvas_user as default arg to friends_get
public $canvas_user;
@@ -657,7 +657,7 @@ function toggleDisplay(id, type) {
* deleted.
*
* IMPORTANT: If your application has registered public tags
* that other applications may be using, do not delete those tags!
* Doing so can break the FBML ofapplications that are using them.
*
* @param array $tag_names the names of the tags to delete (optinal)
@@ -820,7 +820,7 @@ function toggleDisplay(id, type) {
if (is_array($target_ids)) {
$target_ids = json_encode($target_ids);
- $target_ids = trim($target_ids, "[]"); // we do not want square brackets
+ $target_ids = trim($target_ids, "[]"); // we don't want square brackets
}
return $this->call_method('facebook.feed.publishUserAction',
@@ -46,7 +46,7 @@ class FacebookRestClient {
public $added;
public $is_user;
- // we do not pass friends list to iframes, but we want to make
+ // we don't pass friends list to iframes, but we want to make
// friends_get really simple in the canvas_user (non-logged in) case.
// So we use the canvas_user as default arg to friends_get
@@ -657,7 +657,7 @@ function toggleDisplay(id, type) {
*
* IMPORTANT: If your application has registered public tags
- * that other applications may be using, do not delete those tags!
+ * that other applications may be using, don't delete those tags!
* Doing so can break the FBML ofapplications that are using them.
*